TIMEZONES = [
    {
        "offset": 10.5,
        "name": "Australian Central Daylight Time",
        "code": "ACDT"
    },
    {
        "offset": 9.5,
        "name": "Australian Central Standard Time",
        "code": "ACST"
    },
    {
        "offset": -3.0,
        "name": "Atlantic Daylight Time",
        "code": "UNUSED_ADT"
    },
    {
        "offset": -3.0,
        "name": "Atlantic Daylight Time",
        "code": "ADT"
    },
    {
        "offset": 11.0,
        "name": "Australian Eastern Daylight Time",
        "code": "AEDT"
    },
    {
        "offset": 10.0,
        "name": "Australian Eastern Standard Time",
        "code": "AEST"
    },
    {
        "offset": 4.5,
        "name": "Afghanistan Time",
        "code": "AFT"
    },
    {
        "offset": -8.0,
        "name": "Alaska Daylight Time",
        "code": "AKDT"
    },
    {
        "offset": -9.0,
        "name": "Alaska Standard Time",
        "code": "AKST"
    },
    {
        "offset": 6.0,
        "name": "Alma-Ata Time",
        "code": "ALMT"
    },
    {
        "offset": 5.0,
        "name": "Armenia Summer Time",
        "code": "UNUSED_AMST"
    },
    {
        "offset": -3.0,
        "name": "Amazon Summer Time",
        "code": "AMST"
    },
    {
        "offset": 4.0,
        "name": "Armenia Time",
        "code": "UNUSED_AMT"
    },
    {
        "offset": -4.0,
        "name": "Amazon Time",
        "code": "AMT"
    },
    {
        "offset": 12.0,
        "name": "Anadyr Summer Time",
        "code": "ANAST"
    },
    {
        "offset": 12.0,
        "name": "Anadyr Time",
        "code": "ANAT"
    },
    {
        "offset": 5.0,
        "name": "Aqtobe Time",
        "code": "AQTT"
    },
    {
        "offset": -3.0,
        "name": "Argentina Time",
        "code": "ART"
    },
    {
        "offset": 3.0,
        "name": "Arabia Standard Time",
        "code": "UNUSED_AST"
    },
    {
        "offset": -4.0,
        "name": "Atlantic Standard Time",
        "code": "AST"
    },
    {
        "offset": 9.0,
        "name": "Australian Western Daylight Time",
        "code": "AWDT"
    },
    {
        "offset": 8.0,
        "name": "Australian Western Standard Time",
        "code": "AWST"
    },
    {
        "offset": 0.0,
        "name": "Azores Summer Time",
        "code": "AZOST"
    },
    {
        "offset": -1.0,
        "name": "Azores Time",
        "code": "AZOT"
    },
    {
        "offset": 5.0,
        "name": "Azerbaijan Summer Time",
        "code": "AZST"
    },
    {
        "offset": 4.0,
        "name": "Azerbaijan Time",
        "code": "AZT"
    },
    {
        "offset": 8.0,
        "name": "Brunei Darussalam Time",
        "code": "BNT"
    },
    {
        "offset": -4.0,
        "name": "Bolivia Time",
        "code": "BOT"
    },
    {
        "offset": -2.0,
        "name": "Brasilia Summer Time",
        "code": "BRST"
    },
    {
        "offset": -3.0,
        "name": "Brasília time",
        "code": "BRT"
    },
    {
        "offset": 6.0,
        "name": "Bangladesh Standard Time",
        "code": "BST"
    },
    {
        "offset": 1.0,
        "name": "British Summer Time",
        "code": "UNUSED_BST"
    },
    {
        "offset": 6.0,
        "name": "Bhutan Time",
        "code": "BTT"
    },
    {
        "offset": 8.0,
        "name": "Casey Time",
        "code": "CAST"
    },
    {
        "offset": 2.0,
        "name": "Central Africa Time",
        "code": "CAT"
    },
    {
        "offset": 6.5,
        "name": "Cocos Islands Time",
        "code": "CCT"
    },
    {
        "offset": -4.0,
        "name": "Cuba Daylight Time",
        "code": "UNUSED_CDT"
    },
    {
        "offset": -5.0,
        "name": "Central Daylight Time",
        "code": "CDT"
    },
    {
        "offset": 2.0,
        "name": "Central European Summer Time",
        "code": "CEST"
    },
    {
        "offset": 1.0,
        "name": "Central European Time",
        "code": "CET"
    },
    {
        "offset": 13.75,
        "name": "Chatham Island Daylight Time",
        "code": "CHADT"
    },
    {
        "offset": 12.75,
        "name": "Chatham Island Standard Time",
        "code": "CHAST"
    },
    {
        "offset": -10.0,
        "name": "Cook Island Time",
        "code": "CKT"
    },
    {
        "offset": -3.0,
        "name": "Chile Summer Time",
        "code": "CLST"
    },
    {
        "offset": -4.0,
        "name": "Chile Standard Time",
        "code": "CLT"
    },
    {
        "offset": -5.0,
        "name": "Colombia Time",
        "code": "COT"
    },
    {
        "offset": 8.0,
        "name": "China Standard Time",
        "code": "UNUSED_CST"
    },
    {
        "offset": -6.0,
        "name": "Central Standard Time",
        "code": "CST"
    },
    {
        "offset": -5.0,
        "name": "Cuba Standard Time",
        "code": "UNUSED_CST"
    },
    {
        "offset": -1.0,
        "name": "Cape Verde Time",
        "code": "CVT"
    },
    {
        "offset": 7.0,
        "name": "Christmas Island Time",
        "code": "CXT"
    },
    {
        "offset": 10.0,
        "name": "Chamorro Standard Time",
        "code": "ChST"
    },
    {
        "offset": 7.0,
        "name": "Davis Time",
        "code": "DAVT"
    },
    {
        "offset": -5.0,
        "name": "Easter Island Summer Time",
        "code": "EASST"
    },
    {
        "offset": -6.0,
        "name": "Easter Island Standard Time",
        "code": "EAST"
    },
    {
        "offset": 3.0,
        "name": "Eastern Africa Time",
        "code": "UNUSED_EAT"
    },
    {
        "offset": 3.0,
        "name": "East Africa Time",
        "code": "EAT"
    },
    {
        "offset": -5.0,
        "name": "Ecuador Time",
        "code": "ECT"
    },
    {
        "offset": -4.0,
        "name": "Eastern Daylight Time",
        "code": "EDT"
    },
    {
        "offset": 3.0,
        "name": "Eastern European Summer Time",
        "code": "EEST"
    },
    {
        "offset": 2.0,
        "name": "Eastern European Time",
        "code": "EET"
    },
    {
        "offset": 0.0,
        "name": "Eastern Greenland Summer Time",
        "code": "EGST"
    },
    {
        "offset": -1.0,
        "name": "East Greenland Time",
        "code": "EGT"
    },
    {
        "offset": -5.0,
        "name": "Eastern Standard Time",
        "code": "EST"
    },
    {
        "offset": 13.0,
        "name": "Fiji Summer Time",
        "code": "FJST"
    },
    {
        "offset": 12.0,
        "name": "Fiji Time",
        "code": "FJT"
    },
    {
        "offset": -3.0,
        "name": "Falkland Islands Summer Time",
        "code": "FKST"
    },
    {
        "offset": -4.0,
        "name": "Falkland Island Time",
        "code": "FKT"
    },
    {
        "offset": -2.0,
        "name": "Fernando de Noronha Time",
        "code": "FNT"
    },
    {
        "offset": -6.0,
        "name": "Galapagos Time",
        "code": "GALT"
    },
    {
        "offset": -9.0,
        "name": "Gambier Time",
        "code": "GAMT"
    },
    {
        "offset": 4.0,
        "name": "Georgia Standard Time",
        "code": "GET"
    },
    {
        "offset": -3.0,
        "name": "French Guiana Time",
        "code": "GFT"
    },
    {
        "offset": 12.0,
        "name": "Gilbert Island Time",
        "code": "GILT"
    },
    {
        "offset": 0.0,
        "name": "Greenwich Mean Time",
        "code": "GMT"
    },
    {
        "offset": 4.0,
        "name": "Gulf Standard Time",
        "code": "GST"
    },
    {
        "offset": -4.0,
        "name": "Guyana Time",
        "code": "GYT"
    },
    {
        "offset": -3.0,
        "name": "Heure Avancée de l'Atlantique",
        "code": "HAA"
    },
    {
        "offset": -5.0,
        "name": "Heure Avancée du Centre",
        "code": "HAC"
    },
    {
        "offset": -9.0,
        "name": "Hawaii-Aleutian Daylight Time",
        "code": "HADT"
    },
    {
        "offset": -4.0,
        "name": "Heure Avancée de l'Est",
        "code": "HAE"
    },
    {
        "offset": -7.0,
        "name": "Heure Avancée du Pacifique",
        "code": "HAP"
    },
    {
        "offset": -6.0,
        "name": "Heure Avancée des Rocheuses",
        "code": "HAR"
    },
    {
        "offset": -10.0,
        "name": "Hawaii-Aleutian Standard Time",
        "code": "HAST"
    },
    {
        "offset": -2.5,
        "name": "Heure Avancée de Terre-Neuve",
        "code": "HAT"
    },
    {
        "offset": -8.0,
        "name": "Heure Avancée du Yukon",
        "code": "HAY"
    },
    {
        "offset": 8.0,
        "name": "Hong Kong Time",
        "code": "HKT"
    },
    {
        "offset": -4.5,
        "name": "Hora Legal de Venezuela",
        "code": "HLV"
    },
    {
        "offset": -4.0,
        "name": "Heure Normale de l'Atlantique",
        "code": "HNA"
    },
    {
        "offset": -6.0,
        "name": "Heure Normale du Centre",
        "code": "HNC"
    },
    {
        "offset": -5.0,
        "name": "Heure Normale de l'Est",
        "code": "HNE"
    },
    {
        "offset": -8.0,
        "name": "Heure Normale du Pacifique",
        "code": "HNP"
    },
    {
        "offset": -7.0,
        "name": "Heure Normale des Rocheuses",
        "code": "HNR"
    },
    {
        "offset": -3.5,
        "name": "Heure Normale de Terre-Neuve",
        "code": "HNT"
    },
    {
        "offset": -9.0,
        "name": "Heure Normale du Yukon",
        "code": "HNY"
    },
    {
        "offset": 7.0,
        "name": "Hovd Time",
        "code": "HOVT"
    },
    {
        "offset": 7.0,
        "name": "Indochina Time",
        "code": "ICT"
    },
    {
        "offset": 3.0,
        "name": "Israel Daylight Time",
        "code": "IDT"
    },
    {
        "offset": 6.0,
        "name": "Indian Chagos Time",
        "code": "IOT"
    },
    {
        "offset": 4.5,
        "name": "Iran Daylight Time",
        "code": "IRDT"
    },
    {
        "offset": 9.0,
        "name": "Irkutsk Summer Time",
        "code": "IRKST"
    },
    {
        "offset": 9.0,
        "name": "Irkutsk Time",
        "code": "IRKT"
    },
    {
        "offset": 3.5,
        "name": "Iran Standard Time",
        "code": "IRST"
    },
    {
        "offset": 2.0,
        "name": "Israel Standard Time",
        "code": "UNUSED_IST"
    },
    {
        "offset": 5.5,
        "name": "India Standard Time",
        "code": "IST"
    },
    {
        "offset": 1.0,
        "name": "Irish Standard Time",
        "code": "IST"
    },
    {
        "offset": 9.0,
        "name": "Japan Standard Time",
        "code": "JST"
    },
    {
        "offset": 6.0,
        "name": "Kyrgyzstan Time",
        "code": "KGT"
    },
    {
        "offset": 8.0,
        "name": "Krasnoyarsk Summer Time",
        "code": "KRAST"
    },
    {
        "offset": 8.0,
        "name": "Krasnoyarsk Time",
        "code": "KRAT"
    },
    {
        "offset": 9.0,
        "name": "Korea Standard Time",
        "code": "KST"
    },
    {
        "offset": 4.0,
        "name": "Kuybyshev Time",
        "code": "KUYT"
    },
    {
        "offset": 11.0,
        "name": "Lord Howe Daylight Time",
        "code": "LHDT"
    },
    {
        "offset": 10.5,
        "name": "Lord Howe Standard Time",
        "code": "LHST"
    },
    {
        "offset": 14.0,
        "name": "Line Islands Time",
        "code": "LINT"
    },
    {
        "offset": 12.0,
        "name": "Magadan Summer Time",
        "code": "MAGST"
    },
    {
        "offset": 12.0,
        "name": "Magadan Time",
        "code": "MAGT"
    },
    {
        "offset": -9.5,
        "name": "Marquesas Time",
        "code": "MART"
    },
    {
        "offset": 5.0,
        "name": "Mawson Time",
        "code": "MAWT"
    },
    {
        "offset": -6.0,
        "name": "Mountain Daylight Time",
        "code": "MDT"
    },
    {
        "offset": 2.0,
        "name": "Mitteleuropäische Sommerzeit",
        "code": "MESZ"
    },
    {
        "offset": 1.0,
        "name": "Mitteleuropäische Zeit",
        "code": "MEZ"
    },
    {
        "offset": 12.0,
        "name": "Marshall Islands Time",
        "code": "MHT"
    },
    {
        "offset": 6.5,
        "name": "Myanmar Time",
        "code": "MMT"
    },
    {
        "offset": 4.0,
        "name": "Moscow Daylight Time",
        "code": "MSD"
    },
    {
        "offset": 4.0,
        "name": "Moscow Standard Time",
        "code": "MSK"
    },
    {
        "offset": -7.0,
        "name": "Mountain Standard Time",
        "code": "MST"
    },
    {
        "offset": 4.0,
        "name": "Mauritius Time",
        "code": "MUT"
    },
    {
        "offset": 5.0,
        "name": "Maldives Time",
        "code": "MVT"
    },
    {
        "offset": 8.0,
        "name": "Malaysia Time",
        "code": "MYT"
    },
    {
        "offset": 11.0,
        "name": "New Caledonia Time",
        "code": "NCT"
    },
    {
        "offset": -2.5,
        "name": "Newfoundland Daylight Time",
        "code": "NDT"
    },
    {
        "offset": 11.5,
        "name": "Norfolk Time",
        "code": "NFT"
    },
    {
        "offset": 7.0,
        "name": "Novosibirsk Summer Time",
        "code": "NOVST"
    },
    {
        "offset": 6.0,
        "name": "Novosibirsk Time",
        "code": "NOVT"
    },
    {
        "offset": 5.75,
        "name": "Nepal Time",
        "code": "NPT"
    },
    {
        "offset": -3.5,
        "name": "Newfoundland Standard Time",
        "code": "NST"
    },
    {
        "offset": -11.0,
        "name": "Niue Time",
        "code": "NUT"
    },
    {
        "offset": 13.0,
        "name": "New Zealand Daylight Time",
        "code": "NZDT"
    },
    {
        "offset": 12.0,
        "name": "New Zealand Standard Time",
        "code": "NZST"
    },
    {
        "offset": 7.0,
        "name": "Omsk Summer Time",
        "code": "OMSST"
    },
    {
        "offset": 7.0,
        "name": "Omsk Standard Time",
        "code": "OMST"
    },
    {
        "offset": -7.0,
        "name": "Pacific Daylight Time",
        "code": "PDT"
    },
    {
        "offset": -5.0,
        "name": "Peru Time",
        "code": "PET"
    },
    {
        "offset": 12.0,
        "name": "Kamchatka Summer Time",
        "code": "PETST"
    },
    {
        "offset": 12.0,
        "name": "Kamchatka Time",
        "code": "PETT"
    },
    {
        "offset": 10.0,
        "name": "Papua New Guinea Time",
        "code": "PGT"
    },
    {
        "offset": 13.0,
        "name": "Phoenix Island Time",
        "code": "PHOT"
    },
    {
        "offset": 8.0,
        "name": "Philippine Time",
        "code": "PHT"
    },
    {
        "offset": 5.0,
        "name": "Pakistan Standard Time",
        "code": "PKT"
    },
    {
        "offset": -2.0,
        "name": "Pierre & Miquelon Daylight Time",
        "code": "PMDT"
    },
    {
        "offset": -3.0,
        "name": "Pierre & Miquelon Standard Time",
        "code": "PMST"
    },
    {
        "offset": 11.0,
        "name": "Pohnpei Standard Time",
        "code": "PONT"
    },
    {
        "offset": -8.0,
        "name": "Pacific Standard Time",
        "code": "PST"
    },
    {
        "offset": -8.0,
        "name": "Pitcairn Standard Time",
        "code": "UNUSED_PST"
    },
    {
        "offset": 9.0,
        "name": "Palau Time",
        "code": "PWT"
    },
    {
        "offset": -3.0,
        "name": "Paraguay Summer Time",
        "code": "PYST"
    },
    {
        "offset": -4.0,
        "name": "Paraguay Time",
        "code": "PYT"
    },
    {
        "offset": 4.0,
        "name": "Reunion Time",
        "code": "RET"
    },
    {
        "offset": 4.0,
        "name": "Samara Time",
        "code": "SAMT"
    },
    {
        "offset": 2.0,
        "name": "South Africa Standard Time",
        "code": "SAST"
    },
    {
        "offset": 11.0,
        "name": "Solomon IslandsTime",
        "code": "SBT"
    },
    {
        "offset": 4.0,
        "name": "Seychelles Time",
        "code": "SCT"
    },
    {
        "offset": 8.0,
        "name": "Singapore Time",
        "code": "SGT"
    },
    {
        "offset": -3.0,
        "name": "Suriname Time",
        "code": "SRT"
    },
    {
        "offset": -11.0,
        "name": "Samoa Standard Time",
        "code": "SST"
    },
    {
        "offset": -10.0,
        "name": "Tahiti Time",
        "code": "TAHT"
    },
    {
        "offset": 5.0,
        "name": "French Southern and Antarctic Time",
        "code": "TFT"
    },
    {
        "offset": 5.0,
        "name": "Tajikistan Time",
        "code": "TJT"
    },
    {
        "offset": 13.0,
        "name": "Tokelau Time",
        "code": "TKT"
    },
    {
        "offset": 9.0,
        "name": "East Timor Time",
        "code": "TLT"
    },
    {
        "offset": 5.0,
        "name": "Turkmenistan Time",
        "code": "TMT"
    },
    {
        "offset": 12.0,
        "name": "Tuvalu Time",
        "code": "TVT"
    },
    {
        "offset": 8.0,
        "name": "Ulaanbaatar Time",
        "code": "ULAT"
    },
    {
        "offset": 0.0,
        "name": "Coordinated Universal Time",
        "code": "UTC"
    },
    {
        "offset": -2.0,
        "name": "Uruguay Summer Time",
        "code": "UYST"
    },
    {
        "offset": -3.0,
        "name": "Uruguay Time",
        "code": "UYT"
    },
    {
        "offset": 5.0,
        "name": "Uzbekistan Time",
        "code": "UZT"
    },
    {
        "offset": -4.5,
        "name": "Venezuelan Standard Time",
        "code": "VET"
    },
    {
        "offset": 11.0,
        "name": "Vladivostok Summer Time",
        "code": "VLAST"
    },
    {
        "offset": 11.0,
        "name": "Vladivostok Time",
        "code": "VLAT"
    },
    {
        "offset": 11.0,
        "name": "Vanuatu Time",
        "code": "VUT"
    },
    {
        "offset": 2.0,
        "name": "West Africa Summer Time",
        "code": "WAST"
    },
    {
        "offset": 1.0,
        "name": "West Africa Time",
        "code": "WAT"
    },
    {
        "offset": 1.0,
        "name": "Western European Summer Time",
        "code": "WEST"
    },
    {
        "offset": 1.0,
        "name": "Westeuropäische Sommerzeit",
        "code": "WESZ"
    },
    {
        "offset": 0.0,
        "name": "Western European Time",
        "code": "WET"
    },
    {
        "offset": 0.0,
        "name": "Westeuropäische Zeit",
        "code": "WEZ"
    },
    {
        "offset": 12.0,
        "name": "Wallis and Futuna Time",
        "code": "WFT"
    },
    {
        "offset": -2.0,
        "name": "Western Greenland Summer Time",
        "code": "WGST"
    },
    {
        "offset": -3.0,
        "name": "West Greenland Time",
        "code": "WGT"
    },
    {
        "offset": 7.0,
        "name": "Western Indonesian Time",
        "code": "WIB"
    },
    {
        "offset": 9.0,
        "name": "Eastern Indonesian Time",
        "code": "WIT"
    },
    {
        "offset": 8.0,
        "name": "Central Indonesian Time",
        "code": "WITA"
    },
    {
        "offset": 1.0,
        "name": "Western Sahara Summer Time",
        "code": "UNUSED_WST"
    },
    {
        "offset": 13.0,
        "name": "West Samoa Time",
        "code": "WST"
    },
    {
        "offset": 10.0,
        "name": "Yakutsk Summer Time",
        "code": "YAKST"
    },
    {
        "offset": 10.0,
        "name": "Yakutsk Time",
        "code": "YAKT"
    },
    {
        "offset": 10.0,
        "name": "Yap Time",
        "code": "YAPT"
    },
    {
        "offset": 6.0,
        "name": "Yekaterinburg Summer Time",
        "code": "YEKST"
    },
    {
        "offset": 6.0,
        "name": " Yekaterinburg Time",
        "code": "YEKT"
    }
]
