{
    "3 people at most 500 dollars june 2018, to a very hot destination": {},
    "The 3 of us around $100 at 10:00 on 25th of June to Brussels.": {},
    "The 3 of us around $100 at 10:00 on 25th of June in 2018 to Brussels.": {},
    " For 100 euros I want to go to a skiing resort this year.": {},
    " 5 people went on holiday to Spain in August.": {},
    "I want to fly to Paris for at least 500 dollars in 2017": {},
    "3 people at most 500 dollars 04-06-2017": {},
    "Aug 2": {},
    "Janeiro": {},
    "this winter": {},
    "this Summer": {},
    "Next fall": {},
    "in the next 10 minutes i will leave to france": {},
    "this year": {},
    "next year": {},
    "leave today": {},
    "tomorrow": {},
    "leave tomorrow": {},
    "next week": {},
    "you are week": {},
    "in summer 2017": {},
    "in June summer 2017": {},
    "Summer of '69": {},
    "2017-06-25 00:00:00": {},
    "2017-06-25 00:00:00.123123": {},
    "2017-06-25 00:01:01": {},
    "00:01:01 2017-06-25": {},
    "2015-06-07": {},
    "3:00pm": {},
    "3:00 pm": {},
    "12:00 pm": {},
    "3 pm": {},
    "three pm": {},
    "3.00pm": {},
    "a year earlier": {},
    "in 3 weeks and 5 days": {},
    "The 3 of us will each buy 2 cars 2 weeks after 5th of June in 2018 at 10:05:01 for 100 dollars.": {},
    "The 3 of us will each buy 2 cars 2 weeks after 5th of June in 2018 for 100 dollars.": {},
    "some text (March 9, 1990) more text": {},
    "some text (March 9th, 1990) more text": {},
    "March 9, 1990": {},
    "1 week and one day ago": {},
    "friday in two weeks": {},
    "for 2 weeks": {},
    "for 2 weeks and 5 days": {},
    "previous monday": {},
    "Tue two weeks ago": {},
    "last wednesday": {},
    "last wednesday last June": {},
    "in the first 10 days of June": {},
    "over the next five days": {},
    "over the next twenty 4 years": {},
    "during the first five and a half days of June": {},
    "over the last five and a half days of June": {},
    "from Saturday to Thursday inclusive": {},
    "from a year earlier": {},
    "in the first 20 days": {},
    "in the last 20 days of February": {},
    "in the last few days": {},
    "Three interesting dates are 18 Feb 1997": {},
    "next tuesday at 11pm": {},
    "6 days 23 hours 58 minutes": {},
    "between June 16 and 18": {},
    "between June and August at 10pm": {},
    "between June and August at 10:00 p.m.": {},
    "between June and August at ten p.m.": {},
    "today for two days": {},
    "between sunday and saturday": {},
    "during the last 10 days of March": {},
    "last year": {},
    "last quarter": {},
    "next quarter": {},
    "during the first 78 days of the year": {},
    "Three interesting dates are 18 Feb 1997, the 20th of july and 4 days from today.": {},
    "over the first 7 days in 1 month": {},
    "3 months starting next month": {},
    "in the first 2 weeks of next month": {},
    "last 2 weeks next june": {},
    "on the thirty first of june": {},
    "three in the afternoon": {},
    "afternoon": {},
    "in the year nineteen seventy": {},
    "Q1": {},
    "this quarter": {},
    "i will learn french within 3 weeks": {},
    "i will learn french after 3 weeks": {},
    "every 2 weeks between this year and the next until November on Tuesdays and Wednesdays at ten and 11 pm for 10 minutes": {},
    "two weeks tomorrow": {},
    "two weeks ago tomorrow": {}
}
